@@ -35,13 +35,20 @@ sha1 digest of the concatenation of the master password and the domain key::
 
 """
 
+import subprocess
 import optparse
-import sha
+import socket
 import string
 import sys
+import os
 from itertools import izip
 from getpass import getpass
 
+try:
+    from hashlib import sha1
+except:
+    from sha import new as sha1
+
 ONE_BYTE = 2 ** 8
 DEFAULT_LENGTH = 8 # default password length
 DEFAULT_ALPHABET = string.lowercase + string.uppercase + string.digits
@@ -108,7 +115,7 @@ def make_password(master_password, domain_key, lowercase=True, uppercase=True,
     """Build a password out of a master key and a domain key"""
 
     # build the sha1 hash of the concatenation of the keys
-    hash = sha.new(master_password + domain_key).digest()
+    hash = sha1(master_password + domain_key).digest()
 
     if alphabet is None:
         # determine the list of acceptable characters
@@ -137,6 +144,25 @@ def get_password(domain_key=None, lowercase=True, uppercase=True,
                          uppercase=uppercase, digits=digits,
                          length=length, alphabet=alphabet)
 
+def add_key():
+    """print key and launch ssh-add
+    """
+    filename = os.path.expanduser('~/.virtualkeyring')
+    if os.path.isfile(filename):
+        host = open(filename).read()
+        host = host.strip()
+    else:
+        host = socket.gethostname()
+    try:
+        passwd = get_password(host, length=20)
+        print 'Your password for %s is:' % host
+        print passwd
+        raw_input()
+        subprocess.call('clear')
+        subprocess.call('ssh-add')
+    except KeyboardInterrupt:
+        pass
+
 
 def parse_args(args):
     usage = "vkr -l 10 -a abcdefghijklmnopqrstuvwyz0123456789"
@@ -161,11 +187,13 @@ def parse_args(args):
 def main():
     options, _ = parse_args(sys.argv)
 
-    passwd = get_password(length=options.length,
-                          alphabet=options.alphabet)
-    print "your password is:", passwd
-    print "please clean your console (ctrl-L) after usage"
-
+    try:
+        passwd = get_password(length=options.length,
+                              alphabet=options.alphabet)
+        print "your password is:", passwd
+        print "please clean your console (ctrl-L) after usage"
+    except KeyboardInterrupt:
+        pass
 
 if __name__ == "__main__":
    main()
